@@ -14,24 +14,20 @@ def push_software(fpath, radarType, version_name):
 
     request_url = config['api_url']
 
-    bearer_token = str(get_bearer_token.get_bearer_token())
+    try:
+        bearer_token = str(get_bearer_token.get_bearer_token())
+    except requests.exceptions.HTTPError as e:
+        return "User does not have permission to upload"
 
     headers = {
         'Authorization': 'Bearer ' + bearer_token,
     }
 
-    # if not bearer_token:
-    #     return "Bearer token is empty"
-    # else:
-    #     print('bearer_token: ', bearer_token)
-
     # check if can open file path
     if os.path.isfile(fpath):
-        logger.log(message="ZIP file exists (PS): " + fpath, log_level="info", to_file=True, to_terminal=True)
-        # print("ZIP file exists: " + fpath)
+        logger.log(message="ZIP file exists (push software process): " + fpath, log_level="info", to_file=True, to_terminal=True)
     else:
-        logger.log(message="ZIP not exist (PS): " + fpath, log_level="error", to_file=True, to_terminal=True)
-        # print("ZIP not exist: " + fpath)
+        logger.log(message="ZIP not exist (push software process): " + fpath, log_level="error", to_file=True, to_terminal=True)
         return "ZIP not exist (PS): " + fpath
         
     files = {
@@ -43,11 +39,14 @@ def push_software(fpath, radarType, version_name):
         'versionName': json.dumps(version_name)
     }
 
-    # print('versionName: ', version_name)
-    # print('values.versionName: ', values['versionName'])
-
     logger.log(message="Pushing software to Robin SD...", log_level="info", to_file=True, to_terminal=True)
 
     response = requests.post(request_url + '/api/softwares/softwarefiles', headers=headers, data=values, files=files)
     logger.log(message="Response code: " + str(response.status_code), log_level="info", to_file=True, to_terminal=True)
-    return response.json()
\ No newline at end of file
+
+    try:
+        response.raise_for_status()
+    except requests.exceptions.HTTPError as e:
+        return "Error pushing software: " + str(e)
+
+    return response.json()
