@@ -20,7 +20,7 @@ from robin_sd_upload.supportive_scripts import remove_zip
 
 def arg_parser():
     parser = argparse.ArgumentParser(
-        description='Robin Radar Systems Software Uploader',
+        description='Robin Radar Systems - Software Uploader',
         usage='robin-sd-upload [options]',
         prog='Robin Radar Systems Software Uploader',
         epilog='To report any bugs or issues, please visit: \
